@@ -1,7 +1,12 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 import logging
-from nameparser import u, text_type
-from nameparser.constants import *
+from nameparser.util import u
+from nameparser.util import text_type
+from nameparser.util import lc
+from nameparser.config import CONSTANTS
+from nameparser.config import Constants
 
 # http://code.google.com/p/python-nameparser/issues/detail?id=10
 log = logging.getLogger('HumanName')
@@ -17,56 +22,57 @@ log.setLevel(logging.ERROR)
 ENCODING = 'utf-8'
 
 
-def lc(value):
-    """Lower case and remove any periods to normalize for comparison."""
-    if not value:
-        return u''
-    return value.lower().replace('.','')
-
-
-def is_an_initial(value):
-    return re_initial.match(value) or False
-
-
-class BlankHumanNameError(AttributeError):
-    # deprecated in v0.2.5, no longer used
-    pass
-
-
 class HumanName(object):
-    
     """
     Parse a person's name into individual components.
     
-        * o.title
-        * o.first
-        * o.middle
-        * o.last
-        * o.suffix
-        * o.nickname
-     
+    Instantiation assigns to ``full_name``, and assignment to :py:attr:`full_name`
+    triggers :py:func:`parse_full_name`. After parsing the name, these instance 
+    attributes are available.
+    
+    **HumanName Instance Attributes**
+    
+    * :py:attr:`title`
+    * :py:attr:`first`
+    * :py:attr:`middle`
+    * :py:attr:`last`
+    * :py:attr:`suffix`
+    * :py:attr:`nickname`
+    
+    :param str full_name: The name string to be parsed.
+    :param constants constants: 
+        a :py:class:`~nameparser.config.Constants` instance. Pass ``None`` for 
+        `per-instance config <customize.html>`_. 
+    :param str encoding: string representing the encoding of your input
+    :param str string_format: python string formatting 
     """
     
-    def __init__(self, full_name=u"", titles_c=TITLES, prefixes_c=PREFIXES, 
-        suffixes_c=SUFFIXES, punc_titles_c=PUNC_TITLES, conjunctions_c=CONJUNCTIONS,
-        first_name_titles_c=FIRST_NAME_TITLES,
-        capitalization_exceptions_c=dict(CAPITALIZATION_EXCEPTIONS), encoding=ENCODING,
-        string_format=None):
+    has_own_config = False
+    """True if this instance is not using the shared module-level configuration."""
+    
+    C = CONSTANTS
+    """
+    A reference to the configuration for this instance, which may or may not be a
+    reference to the module-wide instance at :py:mod:`~nameparser.config.CONSTANTS`.
+    See `Customizing the Parser <customize.html>`_.
+    """
+    
+    count = 0
+    _members = ['title','first','middle','last','suffix','nickname']
+    unparsable = True
+    _full_name = ''
+    
+    def __init__(self, full_name="", constants=CONSTANTS, encoding=ENCODING, 
+                string_format=None):
+        global CONSTANTS
+        self.C = constants
+        if not self.C:
+            self.C = Constants()
+        if self.C is not CONSTANTS:
+            self.has_own_config = True
         
         self.ENCODING = encoding
-        self.TITLES_C = titles_c
-        self.FIRST_NAME_TITLES_C = first_name_titles_c
-        self.PUNC_TITLES_C = punc_titles_c
-        self.CONJUNCTIONS_C = conjunctions_c
-        self.PREFIXES_C = prefixes_c
-        self.SUFFIXES_C = suffixes_c
-        self.CAPITALIZATION_EXCEPTIONS_C = capitalization_exceptions_c
-        self.SUFFIXES_PREFIXES_TITLES_C = self.SUFFIXES_C | self.PREFIXES_C | self.TITLES_C
         self.string_format = string_format
-        self.count = 0
-        self._members = ['title','first','middle','last','suffix']
-        self.unparsable = True
-        self._full_name = u''
         self.full_name = full_name
     
     def __iter__(self):
@@ -81,7 +87,7 @@ class HumanName(object):
     def __eq__(self, other):
         """
         HumanName instances are equal to other objects whose 
-        lower case unicode representations are the same
+        lower case unicode representation is the same.
         """
         return (u(self)).lower() == (u(other)).lower()
     
@@ -108,17 +114,17 @@ class HumanName(object):
 
     def __unicode__(self):
         if self.string_format:
-            # string_format = "{title} {first} {middle} {last} {suffix}"
-            return self.string_format.format(**self._dict)
-        return u" ".join(self)
+            # string_format = "{title} {first} {middle} {last} {suffix} ({nickname})"
+            return self.string_format.format(**self.as_dict())
+        return " ".join(self)
     
     def __str__(self):
         return self.__unicode__()
     
     def __repr__(self):
         if self.unparsable:
-            return u"<%(class)s : [ Unparsable ] >" % {'class': self.__class__.__name__,}
-        return u"<%(class)s : [\n\tTitle: '%(title)s' \n\tFirst: '%(first)s' \n\tMiddle: '%(middle)s' \n\tLast: '%(last)s' \n\tSuffix: '%(suffix)s'\n\tNickname: '%(nickname)s'\n]>" % {
+            return "<%(class)s : [ Unparsable ] >" % {'class': self.__class__.__name__,}
+        return "<%(class)s : [\n\ttitle: '%(title)s' \n\tfirst: '%(first)s' \n\tmiddle: '%(middle)s' \n\tlast: '%(last)s' \n\tsuffix: '%(suffix)s'\n\tnickname: '%(nickname)s'\n]>" % {
             'class': self.__class__.__name__,
             'title': self.title,
             'first': self.first,
@@ -128,43 +134,89 @@ class HumanName(object):
             'nickname': self.nickname,
         }
     
-    @property
-    def _dict(self):
+    def as_dict(self, include_empty=True):
+        """
+        Return the parsed name as a dictionary of its attributes.
+        
+        :param bool include_empty: Include keys in the dictionary for empty name attributes.
+        :rtype: dict
+        
+        .. doctest::
+        
+            >>> name = HumanName("Bob Dole")
+            >>> name.as_dict()
+            {u'last': u'Dole', u'suffix': u'', u'title': u'', u'middle': u'', u'nickname': u'', u'first': u'Bob'}
+            >>> name.as_dict(False)
+            {u'last': u'Dole', u'first': u'Bob'}
+            
+        """
         d = {}
         for m in self._members:
-            d[m] = getattr(self, m)
+            if include_empty:
+                d[m] = getattr(self, m)
+            else:
+                val = getattr(self, m)
+                if val:
+                    d[m] = val
         return d
-    
+        
     ### attributes
     
     @property
     def title(self):
-        return u" ".join(self.title_list)
+        """
+        The person's titles. Any string of consecutive pieces in 
+        :py:mod:`~nameparser.config.titles` or :py:mod:`~nameparser.config.conjunctions`
+        at the beginning of :py:attr:`full_name`.
+        """
+        return " ".join(self.title_list)
     
     @property
     def first(self):
-        return u" ".join(self.first_list)
+        """
+        The person's first name. The first name piece after any known 
+        :py:attr:`title` pieces parsed from :py:attr:`full_name`.
+        """
+        return " ".join(self.first_list)
     
     @property
     def middle(self):
-        return u" ".join(self.middle_list)
+        """
+        The person's middle names. All name pieces after the first name and before 
+        the last name parsed from :py:attr:`full_name`.
+        """
+        return " ".join(self.middle_list)
     
     @property
     def last(self):
-        return u" ".join(self.last_list)
+        """
+        The person's last name. The last name piece parsed from 
+        :py:attr:`full_name`.
+        """
+        return " ".join(self.last_list)
     
     @property
     def suffix(self):
-        return u", ".join(self.suffix_list)
+        """
+        The persons's suffixes. Pieces at the end of the name that are found in
+        :py:mod:`~nameparser.config.suffixes`, or pieces that are at the end
+        of comma separated formats, e.g. "Lastname, Title Firstname Middle[,] Suffix 
+        [, Suffix]" parsed from :py:attr:`full_name`.
+        """
+        return ", ".join(self.suffix_list)
     
     @property
     def nickname(self):
-        return u" ".join(self.nickname_list)
+        """
+        The person's nicknames. Any text found inside of quotes (``""``) or 
+        parenthesis (``()``)
+        """
+        return " ".join(self.nickname_list)
     
     ### setter methods
     
     def _set_list(self, attr, value):
-        setattr(self, attr+"_list", self._parse_pieces([value]))
+        setattr(self, attr+"_list", self.parse_pieces([value]))
     
     @title.setter
     def title(self, value):
@@ -190,33 +242,105 @@ class HumanName(object):
     def nickname(self, value):
         self._set_list('nickname', value)
     
-    ### parse helpers
+    ### Parse helpers
     
     def is_title(self, value):
-        return lc(value) in self.TITLES_C or value.lower() in self.PUNC_TITLES_C
+        """Is in the :py:data:`~nameparser.config.titles.TITLES` set."""
+        return lc(value) in self.C.titles
     
     def is_conjunction(self, piece):
-        return lc(piece) in self.CONJUNCTIONS_C and not is_an_initial(piece)
+        """Is in the conjuctions set or :py:func:`is_an_initial()`."""
+        return lc(piece) in self.C.conjunctions and not self.is_an_initial(piece)
     
     def is_prefix(self, piece):
-        return lc(piece) in self.PREFIXES_C and not is_an_initial(piece)
+        """Is in the prefixes set or :py:func:`is_an_initial()`."""
+        return lc(piece) in self.C.prefixes and not self.is_an_initial(piece)
     
     def is_suffix(self, piece):
-        return lc(piece) in self.SUFFIXES_C and not is_an_initial(piece)
+        """Is in the suffixes set or :py:func:`is_an_initial()`."""
+        return lc(piece) in self.C.suffixes and not self.is_an_initial(piece)
     
     def is_rootname(self, piece):
-        '''is not a title, suffix or prefix. Just first, middle, last names.'''
-        return lc(piece) not in self.SUFFIXES_PREFIXES_TITLES_C and not is_an_initial(piece)
+        '''Is not a known title, suffix or prefix. Just first, middle, last names.'''
+        return lc(piece) not in self.C.suffixes_prefixes_titles \
+            and not self.is_an_initial(piece) 
+    
+    def is_an_initial(self, value):
+        """
+        Matches the ``initial`` regular expression in 
+        :py:data:`~nameparser.config.regexes.REGEXES`.
+        """
+        return self.C.regexes.initial.match(value) or False
+
+    # def is_a_roman_numeral(value):
+    #     return re_roman_numeral.match(value) or False
+
     
     ### full_name parser
     
     @property
     def full_name(self):
+        """The name string to be parsed."""
         return self._full_name
     
     @full_name.setter
     def full_name(self, value):
         self._full_name = value
+        self.parse_full_name()
+
+    
+    def pre_process(self):
+        """
+        This method happens at the beginning of the :py:func:`parse_full_name` before
+        any other processing of the string aside from unicode normalization, so
+        it's a good place to do any custom handling in a subclass. 
+        Runs :py:func:`parse_nicknames`.
+        """
+        self.parse_nicknames()
+        
+
+    def post_process(self):
+        """
+        This happens at the end of the :py:func:`parse_full_name` after
+        all other processing has taken place. Runs :py:func:`handle_firstnames`.
+        """
+        self.handle_firstnames()
+
+    def parse_nicknames(self):
+        """
+        The content of parenthesis or double quotes in the name will
+        be treated as nicknames. This happens before any other
+        processing of the name.
+        """
+        # https://code.google.com/p/python-nameparser/issues/detail?id=33
+        re_nickname = self.C.regexes.nickname
+        if re_nickname.search(self._full_name):
+            self.nickname_list = re_nickname.findall(self._full_name)
+            self._full_name = re_nickname.sub('', self._full_name)
+
+    def handle_firstnames(self):
+        """
+        If there are only two parts and one is a title, assume it's a last name
+        instead of a first name. e.g. Mr. Johnson. Unless it's a special title
+        like "Sir", then when it's followed by a single name that name is always
+        a first name. 
+        """
+        if self.title \
+                and len(self) == 2 \
+                and not lc(self.title) in self.C.first_name_titles:
+            self.last, self.first = self.first, self.last
+    
+    def parse_full_name(self):
+        """
+        The main parse method for the parser. This method is run upon assignment to the
+        :py:attr:`full_name` attribute or instantiation.
+
+        Basic flow is to hand off to :py:func:`pre_process` to handle nicknames. It
+        then splits on commas and chooses a code path depending on the number of commas.
+        :py:func:`parse_pieces` then splits those parts on spaces and
+        :py:func:`join_on_conjunctions` joins any pieces next to conjunctions. 
+        """
+        
         self.title_list = []
         self.first_list = []
         self.middle_list = []
@@ -225,143 +349,25 @@ class HumanName(object):
         self.nickname_list = []
         self.unparsable = True
         
-        self._parse_full_name()
-
-    def _parse_pieces(self, parts, additional_parts_count=0):
-        """
-        Split parts on spaces and remove commas, join on conjunctions and lastname prefixes.
-        
-        additional_parts_count: if the comma format contains other parts, we need to know 
-        how many there are to decide if things should be considered a conjunction.
-        """
-        ps = []
-        for part in parts:
-            ps += [x.strip(' ,') for x in part.split(' ')]
-        
-        # if there is a period that is not at the end of a piece, split it on periods
-        pieces = []
-        for piece in ps:
-            if piece[:-1].find('.') >= 0:
-                p = [_f for _f in piece.split('.') if _f]
-                pieces += [x+'.' for x in p]
-            else:
-                pieces += [piece]
-        
-        # join conjunctions to surrounding pieces, e.g.:
-        # ['Mr. and Mrs.'], ['King of the Hill'], ['Jack and Jill'], ['Velasquez y Garcia']
-        
-        for conj in filter(self.is_conjunction, pieces[::-1]): # reverse sorted list
-            
-            # loop through the pieces backwards, starting at the end of the list.
-            # Join conjunctions to the pieces on either side of them.
-            
-            if len(conj) == 1 and len(list(filter(self.is_rootname, pieces))) + additional_parts_count < 4:
-                # if there are only 3 total parts (minus known titles, suffixes and prefixes) 
-                # and this conjunction is a single letter, prefer treating it as an initial
-                # rather than a conjunction.
-                # http://code.google.com/p/python-nameparser/issues/detail?id=11
-                continue
-            
-            try:
-                i = pieces.index((conj))
-            except ValueError:
-                log.error("Couldn't find '{conj}' in pieces. i={i}, pieces={pieces}".format(**locals()))
-                continue
-            
-            if i < len(pieces) - 1: 
-                # if this is not the last piece
-                
-                if self.is_conjunction(pieces[i-1]):
-                    
-                    # if the piece in front of this one is a conjunction too,
-                    # add new_piece (this conjuction and the following piece) 
-                    # to the conjuctions constant so that it is recognized
-                    # as a conjunction in the next loop. 
-                    # e.g. for ["Lord","of","the Universe"], put "the Universe"
-                    # into the conjunctions constant.
-                    
-                    new_piece = u' '.join(pieces[i:i+2])
-                    self.CONJUNCTIONS_C.add(lc(new_piece))
-                    pieces[i] = new_piece
-                    pieces.pop(i+1)
-                    continue
-                
-                new_piece = u' '.join(pieces[i-1:i+2])
-                if self.is_title(pieces[i-1]):
-                    
-                    # if the second name is a title, assume the first one is too and add the 
-                    # two titles with the conjunction between them to the titles constant 
-                    # so the combo we just created gets parsed as a title. 
-                    # e.g. "Mr. and Mrs." becomes a title.
-                    
-                    self.TITLES_C.add(lc(new_piece))
-                
-                pieces[i-1] = new_piece
-                pieces.pop(i)
-                pieces.pop(i)
-        
-        # join prefixes to following lastnames: ['de la Vega'], ['van Buren']
-        prefixes = list(filter(self.is_prefix, pieces))
-        try:
-            for prefix in prefixes:
-                try:
-                    i = pieces.index(prefix)
-                except ValueError:
-                    # if two prefixes in a row ("de la Vega"), have to do 
-                    # extra work to find the index the second time around
-                    def find_p(p):
-                        return p.endswith(prefix) # closure on prefix
-                    m = list(filter(find_p, pieces))
-                    # I wonder if some input will throw an IndexError here. 
-                    # Means it can't find prefix anyore.
-                    i = pieces.index(m[0])
-                pieces[i] = u' '.join(pieces[i:i+2])
-                pieces.pop(i+1)
-        except IndexError:
-            pass
-            
-        log.debug(u"pieces: {0}".format(pieces))
-        return pieces
-    
-    def parse_nicknames(self):
-        """
-        Handling Nicknames
-        ------------------
-
-        The content of parenthesis or double quotes in the name will
-        be treated as nicknames. This happens before any other
-        processing of the name.
-        
-        https://code.google.com/p/python-nameparser/issues/detail?id=33
-        """
-        if re_nickname.search(self._full_name):
-            self.nickname_list = re_nickname.findall(self._full_name)
-            self._full_name = re_nickname.sub('', self._full_name)
-    
-    def _parse_full_name(self):
-        """
-        Parse full name into the buckets
-        """
-        
         if not isinstance(self._full_name, text_type):
             self._full_name = u(self._full_name, self.ENCODING)
         
-        self.parse_nicknames()
+        self.pre_process()
         
         # collapse multiple spaces
-        self._full_name = re.sub(re_spaces, u" ", self._full_name.strip() )
+        self._full_name = self.C.regexes.spaces.sub(" ", self._full_name.strip())
         
         # break up full_name by commas
         parts = [x.strip() for x in self._full_name.split(",")]
         
-        log.debug(u"full_name: {0}".format(self._full_name))
-        log.debug(u"parts: {0}".format(parts))
+        log.debug("full_name: {0}".format(self._full_name))
+        log.debug("parts: {0}".format(parts))
         
         if len(parts) == 1:
             
             # no commas, title first middle middle middle last suffix
             
-            pieces = self._parse_pieces(parts)
+            pieces = self.parse_pieces(parts)
             
             for i, piece in enumerate(pieces):
                 try:
@@ -386,14 +392,14 @@ class HumanName(object):
                 
                 self.middle_list.append(piece)
         else:
-            if lc(parts[1]) in self.SUFFIXES_C:
+            if self.is_suffix(parts[1]):
                 
                 # suffix comma: title first middle last, suffix [, suffix]
                 
                 self.suffix_list += parts[1:]
                 
-                pieces = self._parse_pieces(parts[0].split(' '))
-                log.debug(u"pieces: {0}".format(u(pieces)))
+                pieces = self.parse_pieces(parts[0].split(' '))
+                log.debug("pieces: {0}".format(u(pieces)))
                 
                 for i, piece in enumerate(pieces):
                     try:
@@ -414,9 +420,9 @@ class HumanName(object):
             else:
                 
                 # lastname comma: last, title first middles[,] suffix [,suffix]
-                pieces = self._parse_pieces(parts[1].split(' '), 1)
+                pieces = self.parse_pieces(parts[1].split(' '), 1)
                 
-                log.debug(u"pieces: {0}".format(u(pieces)))
+                log.debug("pieces: {0}".format(u(pieces)))
                 
                 self.last_list.append(parts[0])
                 for i, piece in enumerate(pieces):
@@ -442,19 +448,126 @@ class HumanName(object):
                     pass
                 
         if len(self) < 0:
-            log.info(u"Unparsable full_name: " + self._full_name)
+            log.info("Unparsable full_name: " + self._full_name)
         else:
             self.unparsable = False
             self.post_process()
-    
-    def post_process(self):
-        # if there are only two parts and one is a title,
-        # assume it's a last name instead of a first name.
-        # e.g. Mr. Johnson. 
-        if self.title \
-            and len(self) == 2 and \
-            not lc(self.title) in self.FIRST_NAME_TITLES_C:
-            self.last, self.first = self.first, self.last
+
+    def parse_pieces(self, parts, additional_parts_count=0):
+        """
+        Split parts on spaces and remove commas, join on conjunctions and
+        lastname prefixes.
+        
+        :param list parts: name part strings from the comma split
+        :param int additional_parts_count: 
+        
+            if the comma format contains other parts, we need to know 
+            how many there are to decide if things should be considered a conjunction.
+        :return: pieces split on spaces and joined on conjunctions
+        :rtype: list
+        """
+        
+        ps = []
+        for part in parts:
+            ps += [x.strip(' ,') for x in part.split(' ')]
+        
+        # if there is a period that is not at the end of a piece, split it on periods
+        pieces = []
+        for piece in ps:
+            if piece[:-1].find('.') >= 0:
+                p = [_f for _f in piece.split('.') if _f]
+                pieces += [x+'.' for x in p]
+            else:
+                pieces += [piece]
+        
+        
+        return self.join_on_conjunctions(pieces, additional_parts_count)
+        
+    def join_on_conjunctions(self, pieces, additional_parts_count=0):
+        """
+        Join conjunctions to surrounding pieces, e.g.:
+        ['Mr. and Mrs.'], ['King of the Hill'], ['Jack and Jill'], ['Velasquez y Garcia']
+        
+        :param list pieces: name pieces strings after split on spaces
+        :param int additional_parts_count: 
+        :return: new list with piece next to conjunctions merged into one piece with spaces in it.
+        :rtype: list
+        
+        """
+        
+        for conj in filter(self.is_conjunction, pieces[::-1]): # reverse sorted list
+            
+            # loop through the pieces backwards, starting at the end of the list.
+            # Join conjunctions to the pieces on either side of them.
+            
+            if len(conj) == 1 and \
+                len(list(filter(self.is_rootname, pieces))) + additional_parts_count < 4:
+                # if there are only 3 total parts (minus known titles, suffixes and prefixes) 
+                # and this conjunction is a single letter, prefer treating it as an initial
+                # rather than a conjunction.
+                # http://code.google.com/p/python-nameparser/issues/detail?id=11
+                continue
+            
+            try:
+                i = pieces.index((conj))
+            except ValueError:
+                log.error("Couldn't find '{conj}' in pieces. i={i}, pieces={pieces}".format(**locals()))
+                continue
+            
+            if i < len(pieces) - 1: 
+                # if this is not the last piece
+                
+                if self.is_conjunction(pieces[i-1]):
+                    
+                    # if the piece in front of this one is a conjunction too,
+                    # add new_piece (this conjuction and the following piece) 
+                    # to the conjuctions constant so that it is recognized
+                    # as a conjunction in the next loop. 
+                    # e.g. for ["Lord","of","the Universe"], put "the Universe"
+                    # into the conjunctions constant.
+                    
+                    new_piece = ' '.join(pieces[i:i+2])
+                    self.C.conjunctions.add(new_piece)
+                    pieces[i] = new_piece
+                    pieces.pop(i+1)
+                    continue
+                
+                new_piece = ' '.join(pieces[i-1:i+2])
+                if self.is_title(pieces[i-1]):
+                    
+                    # if the second name is a title, assume the first one is too and add the 
+                    # two titles with the conjunction between them to the titles constant 
+                    # so the combo we just created gets parsed as a title. 
+                    # e.g. "Mr. and Mrs." becomes a title.
+                    
+                    self.C.titles.add(new_piece)
+                
+                pieces[i-1] = new_piece
+                pieces.pop(i)
+                pieces.pop(i)
+        
+        # join prefixes to following lastnames: ['de la Vega'], ['van Buren']
+        prefixes = list(filter(self.is_prefix, pieces))
+        try:
+            for prefix in prefixes:
+                try:
+                    i = pieces.index(prefix)
+                except ValueError:
+                    # if two prefixes in a row ("de la Vega"), have to do 
+                    # extra work to find the index the second time around
+                    def find_p(p):
+                        return p.endswith(prefix) # closure on prefix
+                    m = list(filter(find_p, pieces))
+                    # I wonder if some input will throw an IndexError here. 
+                    # Means it can't find prefix anyore.
+                    i = pieces.index(m[0])
+                pieces[i] = ' '.join(pieces[i:i+2])
+                pieces.pop(i+1)
+        except IndexError:
+            pass
+            
+        log.debug("pieces: {0}".format(pieces))
+        return pieces
     
     
     ### Capitalization Support
@@ -462,13 +575,14 @@ class HumanName(object):
     def cap_word(self, word):
         if self.is_prefix(word) or self.is_conjunction(word):
             return lc(word)
-        if word in self.CAPITALIZATION_EXCEPTIONS_C:
-            return self.CAPITALIZATION_EXCEPTIONS_C[word]
-        mac_match = re_mac.match(word)
+        exceptions = self.C.capitalization_exceptions
+        if word in exceptions:
+            return exceptions[word]
+        mac_match = self.C.regexes.mac.match(word)
         if mac_match:
             def cap_after_mac(m):
                 return m.group(1).capitalize() + m.group(2).capitalize()
-            return re_mac.sub(cap_after_mac, word)
+            return self.C.regexes.mac.sub(cap_after_mac, word)
         else:
             return word.capitalize()
 
@@ -476,35 +590,34 @@ class HumanName(object):
         if not piece:
             return ""
         replacement = lambda m: self.cap_word(m.group(0))
-        return re.sub(re_word, replacement, piece)
+        return self.C.regexes.word.sub(replacement, piece)
 
     def capitalize(self):
         """
-        Capitalization Support
-        ----------------------
-
         The HumanName class can try to guess the correct capitalization 
         of name entered in all upper or lower case. It will not adjust 
         the case of names entered in mixed case.
         
-        Usage::
+        **Usage**
+        
+        .. doctest:: capitalize
         
             >>> name = HumanName('bob v. de la macdole-eisenhower phd')
             >>> name.capitalize()
-            >>> u(name)
+            >>> unicode(name)
             u'Bob V. de la MacDole-Eisenhower Ph.D.'
             >>> # Don't touch good names
             >>> name = HumanName('Shirley Maclaine')
             >>> name.capitalize()
-            >>> u(name) 
+            >>> unicode(name) 
             u'Shirley Maclaine'
         
         """
         name = u(self)
         if not (name == name.upper() or name == name.lower()):
             return
-        self.title_list = self.cap_piece(self.title).split(' ')
-        self.first_list = self.cap_piece(self.first).split(' ')
+        self.title_list  = self.cap_piece(self.title ).split(' ')
+        self.first_list  = self.cap_piece(self.first ).split(' ')
         self.middle_list = self.cap_piece(self.middle).split(' ')
-        self.last_list = self.cap_piece(self.last).split(' ')
-        self.suffix_list = self.cap_piece(self.suffix).split(' ')
+        self.last_list   = self.cap_piece(self.last  ).split(' ')
+        self.suffix_list = self.cap_piece(self.suffix).split(', ')
